@@ -77,7 +77,7 @@ void KDiamond::InfoBar::updateRemainingTime(int remainingSeconds)
     if (seconds < 10) {
         secondString.prepend(QLatin1Char('0'));
     }
-    mTime->setText(i18n("Time left: %1", QString::fromLatin1("%1:%2").arg(minuteString).arg(secondString)));
+    mTime->setText(i18n("Time left: %1", QStringLiteral("%1:%2").arg(minuteString).arg(secondString)));
     //special treatment if game is finished
     if (remainingSeconds == 0) {
         updateMoves(0);
